==> hcs-cli-0.1.188.tar.gz: hcs-cli-0.1.188/hcs_cli/provider/hcs/gold_pattern.py <==
"""
Copyright 2023-2023 VMware Inc.
SPDX-License-Identifier: Apache-2.0

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at
    http://www.apache.org/licenses/LICENSE-2.0
Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
"""

from hcs_core.plan import actions
import hcs_cli.service.ims as ims


def deploy(data: dict, state: dict) -> dict:
    ret = ims.gold_pattern.create(data)
    return ret


def refresh(data: dict, state: dict) -> dict:
    body = data["goldPattern"]
    org_id = body["orgId"]
    if state:
        id = state.get("id")
        if id:
            return ims.gold_pattern.get(id, org_id)

    # search by provider id and name, which is the criteria used by service side verification
    provider_id = body["providerInstanceId"]
    image_name = body["goldPatternDetails"]["data"]["imageName"]
    search = f"providerInstanceId $eq {provider_id} AND goldPatternDetails.data.imageName $eq {image_name}"
    ret = ims.gold_pattern.list(org_id, search=search)
    if ret:
        return ret[0]


def decide(data: dict, state: dict):
    return actions.skip


def destroy(data: dict, state: dict, force: bool) -> dict:
    id = state["id"]
    org_id = data["goldPattern"]["orgId"]
    return ims.gold_pattern.delete(id, org_id)


def eta(action: str, data: dict, state: dict):
    if action == actions.create:
        return "1m"
    if action == actions.delete:
        return "1m"

==> hcs-cli-0.1.194.tar.gz: hcs-cli-0.1.194/hcs_cli/provider/hcs/gold_pattern.py <==
"""
Copyright 2023-2023 VMware Inc.
SPDX-License-Identifier: Apache-2.0

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at
    http://www.apache.org/licenses/LICENSE-2.0
Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
"""

from hcs_core.plan import actions
import hcs_cli.service.ims as ims


def deploy(data: dict, state: dict) -> dict:
    ret = ims.gold_pattern.create(data)
    return ret


def refresh(data: dict, state: dict) -> dict:
    body = data["goldPattern"]
    org_id = body["orgId"]
    if state:
        id = state.get("id")
        if id:
            ret = ims.gold_pattern.get(id, org_id)
            if ret:
                return ret

    # search by provider id and name, which is the criteria used by service side verification
    provider_id = body["providerInstanceId"]
    image_name = body["goldPatternDetails"]["data"]["imageName"]
    search = f"providerInstanceId $eq {provider_id} AND goldPatternDetails.data.imageName $eq {image_name}"
    ret = ims.gold_pattern.list(org_id, search=search)
    if ret:
        return ret[0]


def decide(data: dict, state: dict):
    return actions.skip


def destroy(data: dict, state: dict, force: bool) -> dict:
    id = state["id"]
    org_id = data["goldPattern"]["orgId"]
    return ims.gold_pattern.delete(id, org_id)


def eta(action: str, data: dict, state: dict):
    if action == actions.create:
        return "1m"
    if action == actions.delete:
        return "1m"
